==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/StackedSplineAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalStackedSeriesBaseDescriptionMetadata } from "./HorizontalStackedSeriesBaseDescriptionMetadata";
import { StackedSplineAreaSeriesDescription } from "./StackedSplineAreaSeriesDescription";
/**
 * @hidden
 */
export let StackedSplineAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class StackedSplineAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (StackedSplineAreaSeriesDescriptionMetadata.a == null) {
                StackedSplineAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StackedSplineAreaSeriesDescriptionMetadata.c(StackedSplineAreaSeriesDescriptionMetadata.a);
            }
            if (a.k(StackedSplineAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(StackedSplineAreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalStackedSeriesBaseDescriptionMetadata.c(a);
            a.item("IsSplineShapePartOfRange", "Boolean");
        }
        static d(a) {
            StackedSplineAreaSeriesDescriptionMetadata.b(a);
            a.ad("StackedSplineAreaSeries", () => new StackedSplineAreaSeriesDescription());
            a.ac("StackedSplineAreaSeries", StackedSplineAreaSeriesDescriptionMetadata.a);
        }
    }
    StackedSplineAreaSeriesDescriptionMetadata.$t = markType(StackedSplineAreaSeriesDescriptionMetadata, 'StackedSplineAreaSeriesDescriptionMetadata');
    StackedSplineAreaSeriesDescriptionMetadata.a = null;
    return StackedSplineAreaSeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/StackedSplineAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalStackedSeriesBaseDescriptionMetadata } from "./HorizontalStackedSeriesBaseDescriptionMetadata";
import { StackedSplineAreaSeriesDescription } from "./StackedSplineAreaSeriesDescription";
/**
 * @hidden
 */
export let StackedSplineAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class StackedSplineAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (StackedSplineAreaSeriesDescriptionMetadata.a == null) {
                StackedSplineAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StackedSplineAreaSeriesDescriptionMetadata.c(StackedSplineAreaSeriesDescriptionMetadata.a);
            }
            if (a.k(StackedSplineAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(StackedSplineAreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalStackedSeriesBaseDescriptionMetadata.c(a);
            a.item("IsSplineShapePartOfRange", "Boolean");
        }
        static d(a) {
            StackedSplineAreaSeriesDescriptionMetadata.b(a);
            a.ae("StackedSplineAreaSeries", () => new StackedSplineAreaSeriesDescription());
            a.ad("StackedSplineAreaSeries", StackedSplineAreaSeriesDescriptionMetadata.a);
        }
    }
    StackedSplineAreaSeriesDescriptionMetadata.$t = markType(StackedSplineAreaSeriesDescriptionMetadata, 'StackedSplineAreaSeriesDescriptionMetadata');
    StackedSplineAreaSeriesDescriptionMetadata.a = null;
    return StackedSplineAreaSeriesDescriptionMetadata;
})();
